@@ -27,11 +27,11 @@ from dagstermill import _load_input_parameter, _reconstitute_pipeline_context
 from dagstermill.compat import ExecutionError
 from dagstermill.factory import _find_first_tagged_cell_index, get_papermill_parameters
 from jupyter_client.utils import run_sync
-from origami.client import ClientConfig
+from origami.client import ClientConfig, NoteableClient
 from papermill.iorw import load_notebook_node, write_ipynb
 from papermill.translators import PythonTranslator
 
-from ..client import NoteableClient
+from ..util import removeprefix
 from .context import SerializableExecutionContext
 
 
@@ -88,7 +88,7 @@ def _dm_compute(
                 )
                 job_definition_id = step_execution_context.job_name
                 job_instance_id = step_execution_context.run_id
-                file_id = notebook_path.removeprefix("noteable://")
+                file_id = removeprefix(notebook_path, "noteable://")
                 noteable_parameters = {
                     'job_definition_id': job_definition_id,
                     'job_instance_id': job_instance_id,
@@ -180,6 +180,7 @@ context = cloudpickle.loads(serialized_context)
                             'job_definition_id': job_definition_id,
                             'job_instance_id': job_instance_id,
                         },
+                        logger=step_execution_context.log,
                     )
                 except Exception as ex:
                     step_execution_context.log.warn(
