@@ -2,7 +2,7 @@ import pytest
 from papermill.engines import papermill_engines
 from papermill.translators import papermill_translators
 
-from papermill_origami import NoteableEngine
+from papermill_origami.engine import NoteableEngine
 from papermill_origami.noteable_dagstermill import DagsterTranslator, NoteableDagstermillEngine
 
 
